import { getMonaco } from './monaco.js';
import { fromRange, toRange } from './range.js';
/**
 * Convert a Monaco editor location to an LSP location.
 *
 * @param location The Monaco location to convert.
 * @returns The location as an LSP location.
 */
export function fromLocation(location) {
    return {
        range: fromRange(location.range),
        uri: String(location.uri)
    };
}
/**
 * Convert an LSP location to a Monaco editor location.
 *
 * @param location The LSP location to convert.
 * @returns The location as Monaco editor location.
 */
export function toLocation(location) {
    const { Uri } = getMonaco();
    return {
        range: toRange(location.range),
        uri: Uri.parse(location.uri)
    };
}
